Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: test/mjsunit/debug-step.js

Issue 1744123003: [debugger] fix break locations for assignments and return. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: fixes and addressed comments Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/cctest/test-debug.cc ('k') | test/mjsunit/debug-step-end-of-script.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/mjsunit/debug-step.js
diff --git a/test/mjsunit/debug-step.js b/test/mjsunit/debug-step.js
index bfbea16380cf7396c5c3571c55a0ba9f707d12ab..6f5c8f410c10d623f596fdd3e2f1bbf0513c2c16 100644
--- a/test/mjsunit/debug-step.js
+++ b/test/mjsunit/debug-step.js
@@ -64,9 +64,9 @@ function f() {
// Set a breakpoint on the for statement (line 1).
bp1 = Debug.setBreakPoint(f, 1);
// Check that performing 1000 steps will make i 499.
var step_count = 1000;
result = -1;
f();
-assertEquals(332, result);
+assertEquals(333, result);
Debug.setListener(null);
« no previous file with comments | « test/cctest/test-debug.cc ('k') | test/mjsunit/debug-step-end-of-script.js » ('j') | no next file with comments »
@@ -64,9 +64,9 @@ function f() {
// Set a breakpoint on the for statement (line 1).
bp1 = Debug.setBreakPoint(f, 1);
-// Check that performing 1000 steps will make i 499.
+// Check that performing 1000 steps will make i 333.
var step_count = 1000;
result = -1;

Powered by Google App Engine
This is Rietveld 408576698